<?php

/**
 * @file
 * Build and save the responsive layouts and styles
 *
 * This is the main submit handler for building the core layout and processing
 * the responsive stylesheets. The output is five stylesheets saved to public
 * files - the main responsive layout, two conditional stylesheets, the main
 * responsive styles (the aggregated styles with embedded media queries) and a
 * default layout CSS file (for when desktop first method has been selected).
 */
function mayo_submit_reponsive($values, $theme_name, $path) {
  global $path_to_mayo;
  // Set up some paths we use to get and save files
  $path_to_responsive_css = drupal_get_path('theme', $theme_name) . '/css/';
  $path_to_panels_css = $path_to_mayo . '/layouts/css/';

  // Get the page layout config array
  $layout_variables = page_layout();

  // $layouts will hold all the page level layouts
  $layouts = array();

  // Initialize the $is_default_layout variable, we use this to test against
  $is_default_layout = 'smalltouch-portrait';

  // Holds all styles from the responsive stylesheets
  $responsive_styles = array();

  // Smalltouch Landscape
  if ($values['smalltouch_landscape_layout']) {

    $device = 'smalltouch_landscape';

    // Build an array of page layout settings values
    foreach ($layout_variables as $key => $value) {
      if (isset($values["$device" . '_' . "$value"])) {
        $smalltouch_landscape_layout_data[$value] = check_plain($values["$device" . '_' . "$value"]);
      }
    }
    $layout = mayo_build_page_layout($smalltouch_landscape_layout_data['layout'], $smalltouch_landscape_layout_data['sidebar_first'], $smalltouch_landscape_layout_data['sidebar_second'], $smalltouch_landscape_layout_data['sidebar_unit'], $theme_name);

    $method = $smalltouch_landscape_layout_data['layout'];
    $comment = "/* $device $method */\n";
    $width = "\n" . '#main-wrapper {width:' . $smalltouch_landscape_layout_data['page_width'] . $smalltouch_landscape_layout_data['page_unit'] . '}';
    $media_query = $smalltouch_landscape_layout_data['media_query'];

    // Build the styles string
    $styles = $width . "\n" . $layout;

    // CSS wrapped in the media query
    $css = $comment . '@media ' . $media_query . ' {' . $styles . "\n" . '}';

    // Get and wrap the responsive CSS styles in the relative media query
    $responsive_smalltouch_landscape_css = '';
    if (file_exists($path_to_responsive_css . 'responsive.smalltouch.landscape.css')) {
      $responsive_smalltouch_landscape_css = $path_to_responsive_css . 'responsive.smalltouch.landscape.css';
    }
    // Legacy support for pre 7.x-3.2 subthemes
    elseif (file_exists($path_to_responsive_css . 'responsive.smartphone.landscape.css')) {
      $responsive_smalltouch_landscape_css = $path_to_responsive_css . 'responsive.smartphone.landscape.css';
    }
    if (!empty($responsive_smalltouch_landscape_css)) {
      $responsive_css = drupal_load_stylesheet($responsive_smalltouch_landscape_css, FALSE);
      $responsive_styles[] = '@media ' . $media_query . ' {' . "\n" . $responsive_css . "\n" . '}';
    }

    $layouts[] = $css;
  }

  // Tablet Portrait
  if ($values['tablet_portrait_layout']) {

    $device = 'tablet_portrait';

    // Build an array of page layout settings values
    foreach ($layout_variables as $key => $value) {
      if (isset($values["$device" . '_' . "$value"])) {
        $tablet_portrait_layout_data[$value] = check_plain($values["$device" . '_' . "$value"]);
      }
    }
    // Workaround upgrade issues for some settings
    if ($tablet_portrait_layout_data['layout'] == 'two_col_stack') {
      $tablet_portrait_layout_data['layout'] = 'two_sidebars_right_stack';
    }
    $layout = mayo_build_page_layout($tablet_portrait_layout_data['layout'], $tablet_portrait_layout_data['sidebar_first'], $tablet_portrait_layout_data['sidebar_second'], $tablet_portrait_layout_data['sidebar_unit'], $theme_name);

    $method = $tablet_portrait_layout_data['layout'];
    $comment = "/* $device $method */\n";
    $width = "\n" . '#main-wrapper {width:' . $tablet_portrait_layout_data['page_width'] . $tablet_portrait_layout_data['page_unit'] . '}';
    $media_query = $tablet_portrait_layout_data['media_query'];

    // Build the styles string
    $styles = $width . "\n" . $layout;

    // CSS wrapped in the media query
    $css = $comment . '@media ' . $media_query . ' {' . $styles . "\n" . '}';

     // Get and wrap the responsive CSS styles in the relative media query
    //if (file_exists($path_to_responsive_css . 'responsive.tablet.portrait.css')) {
      $responsive_css = drupal_load_stylesheet($path_to_responsive_css . 'responsive.tablet.portrait.css', FALSE);
      $responsive_styles[] = '@media ' . $media_query . ' {' . "\n" . $responsive_css . "\n" . '}';
    //}

    $layouts[] = $css;
  }

  // Tablet Landscape
  if ($values['tablet_landscape_layout']) {

    $device = 'tablet_landscape';

    // Build an array of page layout settings values
    foreach ($layout_variables as $key => $value) {
      if (isset($values["$device" . '_' . "$value"])) {
        $tablet_landscape_layout_data[$value] = check_plain($values["$device" . '_' . "$value"]);
      }
    }
    // Workaround upgrade issues for some settings
    if ($tablet_portrait_layout_data['layout'] == 'two_col_stack') {
      $tablet_portrait_layout_data['layout'] = 'two_sidebars_right_stack';
    }
    $layout = mayo_build_page_layout($tablet_landscape_layout_data['layout'], $tablet_landscape_layout_data['sidebar_first'], $tablet_landscape_layout_data['sidebar_second'], $tablet_landscape_layout_data['sidebar_unit'], $theme_name);

    $method = $tablet_landscape_layout_data['layout'];
    $comment = "/* $device $method */\n";
    $width = "\n" . '#main-wrapper {width:' . $tablet_landscape_layout_data['page_width'] . $tablet_landscape_layout_data['page_unit'] . '}';
    $media_query = $tablet_landscape_layout_data['media_query'];

    // Build the styles string
    $styles = $width . "\n" . $layout;

    // CSS wrapped in the media query
    $css = $comment . '@media ' . $media_query . ' {' . $styles . "\n" . '}';

     // Get and wrap the responsive CSS styles in the relative media query
    //if (file_exists($path_to_responsive_css . 'responsive.tablet.landscape.css')) {
      $responsive_css = drupal_load_stylesheet($path_to_responsive_css . 'responsive.tablet.landscape.css', FALSE);
      $responsive_styles[] = '@media ' . $media_query . ' {' . "\n" . $responsive_css . "\n" . '}';
    //}

    $layouts[] = $css;
  }
  // Standard Layout (bigscreen)
  if ($values['bigscreen_layout']) {

    $device = 'bigscreen';
    // Build an array of page layout settings values
    foreach ($layout_variables as $key => $value) {
      if (isset($values["$device" . '_' . "$value"])) {
        $bigscreen_layout_data[$value] = check_plain($values["$device" . '_' . "$value"]);
      }
    }
    $layout = mayo_build_page_layout($bigscreen_layout_data['layout'], $bigscreen_layout_data['sidebar_first'], $bigscreen_layout_data['sidebar_second'], $bigscreen_layout_data['sidebar_unit'], $theme_name);

    $method = $bigscreen_layout_data['layout'];
    $comment = "/* $device $method */";
    $width = "\n" . '#main-wrapper {width:' . $bigscreen_layout_data['page_width'] . $bigscreen_layout_data['page_unit'] . '}';
    $media_query = $bigscreen_layout_data['media_query'];

    // Standard layout can have a max-width
    $values['bigscreen_set_max_width'] = 0;
    if ($values['bigscreen_set_max_width'] === 1 && $bigscreen_layout_data['page_unit'] === '%') {
      if (!empty($values['bigscreen_max_width'])) {
        $width = "\n" . '#main-wrapper {width:' . $bigscreen_layout_data['page_width'] . $bigscreen_layout_data['page_unit'] . ';max-width:' . $values['bigscreen_max_width'] . $values['bigscreen_max_width_unit'] . '}';
      }
      else {
        $width = "\n" . '#main-wrapper {width:' . $bigscreen_layout_data['page_width'] . $bigscreen_layout_data['page_unit'] . ';max-width:' . $values['bigscreen_max_width'] . $values['bigscreen_max_width_unit'] . '}';
      }
    }

    // Build the styles string
    $styles = $width . "\n" . $layout;
    $css = $comment . "\n" . '@media ' . $media_query . ' {' . $styles . "\n" . '}';

    // add $css to the layouts array
    $layouts[] = $css;
  }
  //****** END bigscreen layout ******//

  // Get and wrap the responsive CSS styles in the relative media query
  //if (file_exists($path_to_responsive_css . 'responsive.desktop.css')) {
    $responsive_css = drupal_load_stylesheet($path_to_responsive_css . 'responsive.desktop.css', FALSE);
    $responsive_styles[] = '@media ' . $media_query . ' {' . "\n" . $responsive_css . "\n" . '}';
  //}

  // Generate the layout and responsive styles stylesheets
  // Here we generate five files:
  // 1. $theme_name.default.layout
  // 2. $theme_name.responsive.layout
  // 3. $theme_name.responsive.styles
  // adaptivetheme_preprocess_html() will take care of loading the right ones
  // when they are needed.

  // responsive layout
  $responsive_layout_data = implode("\n", $layouts);
  $responsive_layout = $responsive_layout_data;

  // Aggregate the design stylesheets
  $responsive_css = implode("\n", $responsive_styles);

  // Regex relative paths. This mimics Drupal cores drupal_build_css_cache(), but
  // its not as powerful because assets must be relative to the theme root.
  $_base = base_path() . $path_to_responsive_css;
  _drupal_build_css_path(NULL, $_base);
  $responsive_css = preg_replace_callback('/url\(\s*[\'"]?(?![a-z]+:|\/+)([^\'")]+)[\'"]?\s*\)/i', '_drupal_build_css_path', $responsive_css);

  // Build a keyed array: file names as key, layout data as value
  $files = array(
    //"$theme_name.default.layout" => $desktop_first_layout,
    "$theme_name.responsive.layout" => $responsive_layout,
    //"$theme_name.responsive.styles" => $responsive_css,
  );

  // Loop over the array and save each file, and we're done!
  foreach ($files as $key => $value) {
    $filepath = "$path/$key.css";
    file_unmanaged_save_data($value, $filepath, FILE_EXISTS_REPLACE);
  }
}
